@@ -15,17 +15,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include "lanpairinghandler.h"
+
 #include <KLocalizedString>
 
 #include "core_debug.h"
 #include "daemon.h"
 #include "kdeconnectconfig.h"
 #include "landevicelink.h"
-#include "lanpairinghandler.h"
-#include "networkpackagetypes.h"
+#include "networkpackettypes.h"
 
 LanPairingHandler::LanPairingHandler(DeviceLink* deviceLink)
     : PairingHandler(deviceLink)
@@ -36,7 +37,7 @@ LanPairingHandler::LanPairingHandler(DeviceLink* deviceLink)
     connect(&m_pairingTimeout, &QTimer::timeout, this, &LanPairingHandler::pairingTimeout);
 }
 
-void LanPairingHandler::packageReceived(const NetworkPackage& np)
+void LanPairingHandler::packetReceived(const NetworkPacket& np)
 {
     bool wantsPair = np.get<bool>(QStringLiteral("pair"));
 
@@ -80,8 +81,8 @@ bool LanPairingHandler::requestPairing()
         return acceptPairing();
     }
 
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", true}});
-    const bool success = deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{QStringLiteral("pair"), true}});
+    const bool success = deviceLink()->sendPacket(np);
     if (success) {
         setInternalPairStatus(Requested);
     }
@@ -90,8 +91,8 @@ bool LanPairingHandler::requestPairing()
 
 bool LanPairingHandler::acceptPairing()
 {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", true}});
-    bool success = deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{QStringLiteral("pair"), true}});
+    bool success = deviceLink()->sendPacket(np);
     if (success) {
         setInternalPairStatus(Paired);
     }
@@ -100,21 +101,21 @@ bool LanPairingHandler::acceptPairing()
 
 void LanPairingHandler::rejectPairing()
 {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", false}});
-    deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{QStringLiteral("pair"), false}});
+    deviceLink()->sendPacket(np);
     setInternalPairStatus(NotPaired);
 }
 
 void LanPairingHandler::unpair() {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", false}});
-    deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{QStringLiteral("pair"), false}});
+    deviceLink()->sendPacket(np);
     setInternalPairStatus(NotPaired);
 }
 
 void LanPairingHandler::pairingTimeout()
 {
-    NetworkPackage np(PACKAGE_TYPE_PAIR, {{"pair", false}});
-    deviceLink()->sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PAIR, {{QStringLiteral("pair"), false}});
+    deviceLink()->sendPacket(np);
     setInternalPairStatus(NotPaired); //Will emit the change as well
     Q_EMIT pairingError(i18n("Timed out"));
 }
