@@ -29,6 +29,7 @@
 #include <QDir>
 #include <QStandardPaths>
 #include <QCoreApplication>
+#include <QHostInfo>
 #include <QSettings>
 #include <QSslCertificate>
 #include <QtCrypto>
@@ -52,9 +53,6 @@ struct KdeConnectConfigPrivate {
     QSettings* m_config;
     QSettings* m_trustedDevices;
 
-    QString m_defaultName;
-    QString m_deviceType;
-
 #ifdef USE_PRIVATE_DBUS
     QString m_privateDBusAddress;  // Private DBus Address cache
 #endif
@@ -86,16 +84,21 @@ KdeConnectConfig::KdeConnectConfig()
     d->m_config = new QSettings(baseConfigDir().absoluteFilePath(QStringLiteral("config")), QSettings::IniFormat);
     d->m_trustedDevices = new QSettings(baseConfigDir().absoluteFilePath(QStringLiteral("trusted_devices")), QSettings::IniFormat);
 
-    d->m_defaultName = Daemon::instance()->defaultName();
-    d->m_deviceType = Daemon::instance()->deviceType();
-
     loadPrivateKey();
     loadCertificate();
 }
 
 QString KdeConnectConfig::name()
 {
-    return d->m_config->value(QStringLiteral("name"), d->m_defaultName).toString();
+    QString username;
+    #ifdef Q_OS_WIN
+        username = QString::fromLatin1(qgetenv("USERNAME"));
+    #else
+        username = QString::fromLatin1(qgetenv("USER"));
+    #endif
+    QString defaultName = username + QStringLiteral("@") + QHostInfo::localHostName();
+    QString name = d->m_config->value(QStringLiteral("name"), defaultName).toString();
+    return name;
 }
 
 void KdeConnectConfig::setName(const QString& name)
@@ -106,7 +109,23 @@ void KdeConnectConfig::setName(const QString& name)
 
 QString KdeConnectConfig::deviceType()
 {
-    return d->m_deviceType;
+#ifdef SAILFISHOS
+    return QStringLiteral("phone");
+#else
+    const QByteArrayList platforms = qgetenv("PLASMA_PLATFORM").split(':');
+
+    if (platforms.contains("phone")) {
+        return QStringLiteral("phone");
+    } else if (platforms.contains("tablet")) {
+        return QStringLiteral("tablet");
+    } else if(platforms.contains("mediacenter")) {
+        return QStringLiteral("tv");
+    }
+
+    // TODO non-Plasma mobile platforms
+
+    return QStringLiteral("desktop");
+#endif
 }
 
 QString KdeConnectConfig::deviceId()
