@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "lockdeviceplugin.h"
@@ -24,15 +24,13 @@
 #include <KPluginFactory>
 
 #include <QDebug>
-#include <QDBusConnection>
-#include <QLoggingCategory>
 #include "screensaverdbusinterface.h"
+#include "plugin_lock_debug.h"
 
 #include <core/device.h>
+#include <dbushelper.h>
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectLockPluginFactory, "kdeconnect_lockdevice.json", registerPlugin<LockDevicePlugin>(); )
-
-Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_LOCKREMOTE, "kdeconnect.plugin.lock")
+K_PLUGIN_CLASS_WITH_JSON(LockDevicePlugin, "kdeconnect_lockdevice.json")
 
 LockDevicePlugin::LockDevicePlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
@@ -52,11 +50,11 @@ bool LockDevicePlugin::isLocked() const
 }
 void LockDevicePlugin::setLocked(bool locked)
 {
-    NetworkPackage np(PACKAGE_TYPE_LOCK_REQUEST, {{"setLocked", locked}});
-    sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_LOCK_REQUEST, {{QStringLiteral("setLocked"), locked}});
+    sendPacket(np);
 }
 
-bool LockDevicePlugin::receivePackage(const NetworkPackage & np)
+bool LockDevicePlugin::receivePacket(const NetworkPacket & np)
 {
     if (np.has(QStringLiteral("isLocked"))) {
         bool locked = np.get<bool>(QStringLiteral("isLocked"));
@@ -72,8 +70,8 @@ bool LockDevicePlugin::receivePackage(const NetworkPackage & np)
         sendState = true;
     }
     if (sendState) {
-        NetworkPackage np(PACKAGE_TYPE_LOCK, QVariantMap {{"isLocked", QVariant::fromValue<bool>(iface()->GetActive())}});
-        sendPackage(np);
+        NetworkPacket np(PACKET_TYPE_LOCK, QVariantMap {{QStringLiteral("isLocked"), QVariant::fromValue<bool>(iface()->GetActive())}});
+        sendPacket(np);
     }
 
     return true;
@@ -82,7 +80,7 @@ bool LockDevicePlugin::receivePackage(const NetworkPackage & np)
 OrgFreedesktopScreenSaverInterface* LockDevicePlugin::iface()
 {
     if (!m_iface) {
-        m_iface = new OrgFreedesktopScreenSaverInterface(QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("/org/freedesktop/ScreenSaver"), QDBusConnection::sessionBus());
+        m_iface = new OrgFreedesktopScreenSaverInterface(QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("/org/freedesktop/ScreenSaver"), DBusHelper::sessionBus());
         if(!m_iface->isValid())
             qCWarning(KDECONNECT_PLUGIN_LOCKREMOTE) << "Couldn't connect to the ScreenSaver interface";
     }
@@ -91,13 +89,13 @@ OrgFreedesktopScreenSaverInterface* LockDevicePlugin::iface()
 
 void LockDevicePlugin::connected()
 {
-    NetworkPackage np(PACKAGE_TYPE_LOCK_REQUEST, {{"requestLocked", QVariant()}});
-    sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_LOCK_REQUEST, {{QStringLiteral("requestLocked"), QVariant()}});
+    sendPacket(np);
 }
 
 QString LockDevicePlugin::dbusPath() const
 {
-    return "/modules/kdeconnect/devices/" + device()->id() + "/lockdevice";
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/lockdevice");
 }
 
 #include "lockdeviceplugin.moc"
