@@ -15,21 +15,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "notificationsdbusinterface.h"
-#include "notification_debug.h"
+#include "plugin_notification_debug.h"
 #include "notification.h"
 
-#include <QDBusConnection>
-
 #include <core/device.h>
 #include <core/kdeconnectplugin.h>
+#include <dbushelper.h>
 
 #include "notificationsplugin.h"
 #include "sendreplydialog.h"
 
+//In older Qt released, qAsConst isnt available
+#include "qtcompat_p.h"
+
 NotificationsDbusInterface::NotificationsDbusInterface(KdeConnectPlugin* plugin)
     : QDBusAbstractAdaptor(const_cast<Device*>(plugin->device()))
     , m_device(plugin->device())
@@ -79,7 +81,7 @@ void NotificationsDbusInterface::processPacket(const NetworkPacket& np)
     Notification* noti = nullptr;
 
     if (!m_internalIdToPublicId.contains(id)) {
-        noti = new Notification(np, this);
+        noti = new Notification(np, m_plugin->device(), this);
 
         if (noti->isReady()) {
             addNotification(noti);
@@ -105,16 +107,18 @@ void NotificationsDbusInterface::addNotification(Notification* noti)
 
     connect(noti, &Notification::dismissRequested,
             this, &NotificationsDbusInterface::dismissRequested);
-    
-    connect(noti, &Notification::replyRequested, this, [this,noti]{ 
-        replyRequested(noti); 
+
+    connect(noti, &Notification::replyRequested, this, [this,noti]{
+        replyRequested(noti);
     });
 
+    connect(noti, &Notification::actionTriggered, this, &NotificationsDbusInterface::sendAction);
+
     const QString& publicId = newId();
     m_notifications[publicId] = noti;
     m_internalIdToPublicId[internalId] = publicId;
 
-    QDBusConnection::sessionBus().registerObject(m_device->dbusPath()+"/notifications/"+publicId, noti, QDBusConnection::ExportScriptableContents);
+    DBusHelper::sessionBus().registerObject(m_device->dbusPath() + QStringLiteral("/notifications/") + publicId, noti, QDBusConnection::ExportScriptableContents);
     Q_EMIT notificationPosted(publicId);
 }
 
@@ -136,7 +140,7 @@ void NotificationsDbusInterface::removeNotification(const QString& internalId)
     }
 
     //Deleting the notification will unregister it automatically
-    //QDBusConnection::sessionBus().unregisterObject(mDevice->dbusPath()+"/notifications/"+publicId);
+    //DBusHelper::sessionBus().unregisterObject(mDevice->dbusPath()+"/notifications/"+publicId);
     noti->deleteLater();
 
     Q_EMIT notificationRemoved(publicId);
@@ -148,7 +152,7 @@ void NotificationsDbusInterface::dismissRequested(const QString& internalId)
     np.set<QString>(QStringLiteral("cancel"), internalId);
     m_plugin->sendPacket(np);
 
-    //Workaround: we erase notifications without waiting a repsonse from the
+    //Workaround: we erase notifications without waiting a response from the
     //phone because we won't receive a response if we are out of sync and this
     //notification no longer exists. Ideally, each time we reach the phone
     //after some time disconnected we should re-sync all the notifications.
@@ -174,6 +178,14 @@ void NotificationsDbusInterface::sendReply(const QString& replyId, const QString
     m_plugin->sendPacket(np);
 }
 
+void NotificationsDbusInterface::sendAction(const QString& key, const QString& action)
+{
+    NetworkPacket np(PACKET_TYPE_NOTIFICATION_ACTION);
+    np.set<QString>(QStringLiteral("key"), key);
+    np.set<QString>(QStringLiteral("action"), action);
+    m_plugin->sendPacket(np);
+}
+
 QString NotificationsDbusInterface::newId()
 {
     return QString::number(++m_lastId);
