@@ -28,13 +28,9 @@
 
 #include <core/kdeconnectplugin.h>
 
-#include <QLoggingCategory>
-
 #include <mmdeviceapi.h>
 #include <endpointvolume.h>
 
-Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_PAUSEMUSIC)
-
 class PauseMusicPlugin
     : public KdeConnectPlugin
 {
