@@ -15,33 +15,26 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "remotecommandsplugin.h"
 
 #include <KPluginFactory>
 
-#include <QDBusConnection>
-#include <QProcess>
-#include <QDir>
-#include <QLoggingCategory>
-#include <QSettings>
-#include <QJsonDocument>
-#include <KShell>
-
 #include <core/networkpacket.h>
 #include <core/device.h>
 
+#include "plugin_remotecommands_debug.h"
+
 #define PACKET_TYPE_RUNCOMMAND_REQUEST QLatin1String("kdeconnect.runcommand.request")
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_remotecommands.json", registerPlugin< RemoteCommandsPlugin >(); )
-
-Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_REMOTECOMMANDS, "kdeconnect.plugin.remotecommands")
+K_PLUGIN_CLASS_WITH_JSON(RemoteCommandsPlugin, "kdeconnect_remotecommands.json")
 
 RemoteCommandsPlugin::RemoteCommandsPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
     , m_commands("{}")
+    , m_canAddCommand(false)
 {
 }
 
@@ -50,6 +43,7 @@ RemoteCommandsPlugin::~RemoteCommandsPlugin() = default;
 bool RemoteCommandsPlugin::receivePacket(const NetworkPacket& np)
 {
     if (np.has(QStringLiteral("commandList"))) {
+        m_canAddCommand = np.get<bool>(QStringLiteral("canAddCommand"));
         setCommands(np.get<QByteArray>(QStringLiteral("commandList")));
         return true;
     }
@@ -59,13 +53,13 @@ bool RemoteCommandsPlugin::receivePacket(const NetworkPacket& np)
 
 void RemoteCommandsPlugin::connected()
 {
-    NetworkPacket np(PACKET_TYPE_RUNCOMMAND_REQUEST, {{"requestCommandList", true}});
+    NetworkPacket np(PACKET_TYPE_RUNCOMMAND_REQUEST, {{QStringLiteral("requestCommandList"), true}});
     sendPacket(np);
 }
 
 QString RemoteCommandsPlugin::dbusPath() const
 {
-    return "/modules/kdeconnect/devices/" + device()->id() + "/remotecommands";
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/remotecommands");
 }
 
 void RemoteCommandsPlugin::setCommands(const QByteArray& cmds)
@@ -78,7 +72,13 @@ void RemoteCommandsPlugin::setCommands(const QByteArray& cmds)
 
 void RemoteCommandsPlugin::triggerCommand(const QString& key)
 {
-    NetworkPacket np(PACKET_TYPE_RUNCOMMAND_REQUEST, {{ "key", key }});
+    NetworkPacket np(PACKET_TYPE_RUNCOMMAND_REQUEST, {{QStringLiteral("key"), key }});
+    sendPacket(np);
+}
+
+void RemoteCommandsPlugin::editCommands()
+{
+    NetworkPacket np(PACKET_TYPE_RUNCOMMAND_REQUEST, {{QStringLiteral("setup"), true }});
     sendPacket(np);
 }
 
