@@ -15,18 +15,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef SHAREPLUGIN_H
 #define SHAREPLUGIN_H
 
-#include <KNotification>
-#include <KIO/Job>
+#include <QPointer>
 
 #include <core/kdeconnectplugin.h>
+#include <core/compositefiletransferjob.h>
 
-#define PACKAGE_TYPE_SHARE_REQUEST QStringLiteral("kdeconnect.share.request")
+#define PACKET_TYPE_SHARE_REQUEST QStringLiteral("kdeconnect.share.request")
+#define PACKET_TYPE_SHARE_REQUEST_UPDATE QStringLiteral("kdeconnect.share.request.update")
 
 class SharePlugin
     : public KdeConnectPlugin
@@ -38,23 +39,28 @@ public:
     explicit SharePlugin(QObject* parent, const QVariantList& args);
 
     ///Helper method, QDBus won't recognize QUrl
-    Q_SCRIPTABLE void shareUrl(const QString& url) { shareUrl(QUrl(url)); }
+    Q_SCRIPTABLE void shareUrl(const QString& url) { shareUrl(QUrl(url), false); }
+    Q_SCRIPTABLE void shareUrls(const QStringList& urls);
+    Q_SCRIPTABLE void shareText(const QString& text);
+    Q_SCRIPTABLE void openFile(const QString& file) { shareUrl(QUrl(file), true); }
 
-    bool receivePackage(const NetworkPackage& np) override;
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override {}
     QString dbusPath() const override;
 
 private Q_SLOTS:
-    void finished(KJob*);
     void openDestinationFolder();
 
 Q_SIGNALS:
-    void shareReceived(const QString& url);
+    Q_SCRIPTABLE void shareReceived(const QString& url);
 
 private:
-    void shareUrl(const QUrl& url);
-
+    void finished(KJob* job, const qint64 dateModified, const bool open);
+    void shareUrl(const QUrl& url, bool open);
     QUrl destinationDir() const;
+    QUrl getFileDestination(const QString filename) const;
+    void setDateModified(const QUrl& destination, const qint64 timestamp);
 
+    QPointer<CompositeFileTransferJob> m_compositeJob;
 };
 #endif
